from typing import ClassVar as _ClassVar
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ImportModelRequest(_message.Message):
    __slots__ = ["file_name", "model_name", "context"]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    file_name: str
    model_name: str
    context: _base_pb2.Context
    def __init__(
        self,
        file_name: _Optional[str] = ...,
        model_name: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ImportModelResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/quant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/rules/quant.proto\x12\x1fpro.omni.oms.api.v1.rules.quant\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf8\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eproduct_doc_id\x18\x02 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x03 \x01(\x05\x12\x14\n\x0cquant_sql_id\x18\x04 \x01(\x05\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc4\x01\n\x12QuantCreateRequest\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x02 \x01(\x05\x12\x14\n\x0cquant_sql_id\x18\x03 \x01(\x05\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantCreateResponse\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11QuantReadResponse\x12\x36\n\x06quants\x18\x01 \x03(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x83\x01\n\x12QuantUpdateRequest\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantUpdateResponse\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"b\n\x12QuantDeleteRequest\x12\x14\n\x0cquant_sql_id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cQuantService\x12z\n\x0bQuantCreate\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantCreateRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantCreateResponse"\x00\x12t\n\tQuantRead\x12\x31.pro.omni.oms.api.v1.rules.quant.QuantReadRequest\x1a\x32.pro.omni.oms.api.v1.rules.quant.QuantReadResponse"\x00\x12z\n\x0bQuantUpdate\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantUpdateRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantUpdateResponse"\x00\x12z\n\x0bQuantDelete\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantDeleteRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.quant_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUANT"]._serialized_start = 109
    _globals["_QUANT"]._serialized_end = 357
    _globals["_QUANTCREATEREQUEST"]._serialized_start = 360
    _globals["_QUANTCREATEREQUEST"]._serialized_end = 556
    _globals["_QUANTCREATERESPONSE"]._serialized_start = 559
    _globals["_QUANTCREATERESPONSE"]._serialized_end = 710
    _globals["_QUANTREADREQUEST"]._serialized_start = 713
    _globals["_QUANTREADREQUEST"]._serialized_end = 1079
    _globals["_QUANTREADRESPONSE"]._serialized_start = 1082
    _globals["_QUANTREADRESPONSE"]._serialized_end = 1291
    _globals["_QUANTUPDATEREQUEST"]._serialized_start = 1294
    _globals["_QUANTUPDATEREQUEST"]._serialized_end = 1425
    _globals["_QUANTUPDATERESPONSE"]._serialized_start = 1428
    _globals["_QUANTUPDATERESPONSE"]._serialized_end = 1579
    _globals["_QUANTDELETEREQUEST"]._serialized_start = 1581
    _globals["_QUANTDELETEREQUEST"]._serialized_end = 1679
    _globals["_QUANTDELETERESPONSE"]._serialized_start = 1681
    _globals["_QUANTDELETERESPONSE"]._serialized_end = 1777
    _globals["_QUANTSERVICE"]._serialized_start = 1780
    _globals["_QUANTSERVICE"]._serialized_end = 2284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/calendar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/calendar.proto\x12"pro.omni.oms.api.v1.rules.calendar\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xa6\x01\n\x08\x43\x61lendar\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x06\x61\x63tive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"r\n\x15\x43\x61lendarCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61lendarCreateResponse\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13\x43\x61lendarReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x14\x43\x61lendarReadResponse\x12?\n\tcalendars\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15\x43\x61lendarUpdateRequest\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61lendarUpdateResponse\x12>\n\x08\x63\x61lendar\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15\x43\x61lendarDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16\x43\x61lendarDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0f\x43\x61lendarService\x12\x89\x01\n\x0e\x43\x61lendarCreate\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarCreateRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarCreateResponse"\x00\x12\x83\x01\n\x0c\x43\x61lendarRead\x12\x37.pro.omni.oms.api.v1.rules.calendar.CalendarReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.calendar.CalendarReadResponse"\x00\x12\x89\x01\n\x0e\x43\x61lendarUpdate\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarUpdateResponse"\x00\x12\x89\x01\n\x0e\x43\x61lendarDelete\x12\x39.pro.omni.oms.api.v1.rules.calendar.CalendarDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.calendar.CalendarDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.calendar_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CALENDAR"]._serialized_start = 115
    _globals["_CALENDAR"]._serialized_end = 281
    _globals["_CALENDARCREATEREQUEST"]._serialized_start = 283
    _globals["_CALENDARCREATEREQUEST"]._serialized_end = 397
    _globals["_CALENDARCREATERESPONSE"]._serialized_start = 400
    _globals["_CALENDARCREATERESPONSE"]._serialized_end = 563
    _globals["_CALENDARREADREQUEST"]._serialized_start = 566
    _globals["_CALENDARREADREQUEST"]._serialized_end = 935
    _globals["_CALENDARREADRESPONSE"]._serialized_start = 938
    _globals["_CALENDARREADRESPONSE"]._serialized_end = 1159
    _globals["_CALENDARUPDATEREQUEST"]._serialized_start = 1162
    _globals["_CALENDARUPDATEREQUEST"]._serialized_end = 1305
    _globals["_CALENDARUPDATERESPONSE"]._serialized_start = 1308
    _globals["_CALENDARUPDATERESPONSE"]._serialized_end = 1471
    _globals["_CALENDARDELETEREQUEST"]._serialized_start = 1473
    _globals["_CALENDARDELETEREQUEST"]._serialized_end = 1564
    _globals["_CALENDARDELETERESPONSE"]._serialized_start = 1566
    _globals["_CALENDARDELETERESPONSE"]._serialized_end = 1665
    _globals["_CALENDARSERVICE"]._serialized_start = 1668
    _globals["_CALENDARSERVICE"]._serialized_end = 2239
# @@protoc_insertion_point(module_scope)



import mongoengine as mongo
from omni.pro.logger import configure_logger
from omni.pro import redis
from omni.pro.config import Config

logger = configure_logger(name=__name__)


def ms_register_connection():
    manager = redis.get_redis_manager()
    tenants = manager.get_tenant_codes()
    # Registrar todas las conexiones
    for idx, tenant in enumerate(tenants):
        logger.info(f"Register connection for tenant {tenant}")
        conn = manager.get_mongodb_config(Config.SERVICE_ID, tenant)
        eval_conn = conn.copy()
        if Config.DEBUG:
            del eval_conn["complement"]
        if not all(eval_conn.values()):
            continue

        mongo.register_connection(
            alias=f"{tenant}_{conn['name']}",
            name=conn["name"],
            host=conn["host"],
            port=int(conn["port"]),
            username=conn["user"],
            password=conn["password"],
            **conn["complement"],
        )

        if idx == 0:
            mongo.register_connection(
                alias=mongo.DEFAULT_CONNECTION_NAME,
                name=mongo.DEFAULT_CONNECTION_NAME,
                host=conn["host"],
                port=int(conn["port"]),
                username=conn["user"],
                password=conn["password"],
                **conn["complement"],
            )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import order_pb2 as v1_dot_sales_dot_order__pb2


class OrderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.OrderCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderCreate",
            request_serializer=v1_dot_sales_dot_order__pb2.OrderCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__pb2.OrderCreateResponse.FromString,
        )
        self.OrderRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderRead",
            request_serializer=v1_dot_sales_dot_order__pb2.OrderReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__pb2.OrderReadResponse.FromString,
        )
        self.OrderUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderUpdate",
            request_serializer=v1_dot_sales_dot_order__pb2.OrderUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__pb2.OrderUpdateResponse.FromString,
        )
        self.OrderDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderDelete",
            request_serializer=v1_dot_sales_dot_order__pb2.OrderDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__pb2.OrderDeleteResponse.FromString,
        )


class OrderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def OrderCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_OrderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "OrderCreate": grpc.unary_unary_rpc_method_handler(
            servicer.OrderCreate,
            request_deserializer=v1_dot_sales_dot_order__pb2.OrderCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__pb2.OrderCreateResponse.SerializeToString,
        ),
        "OrderRead": grpc.unary_unary_rpc_method_handler(
            servicer.OrderRead,
            request_deserializer=v1_dot_sales_dot_order__pb2.OrderReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__pb2.OrderReadResponse.SerializeToString,
        ),
        "OrderUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.OrderUpdate,
            request_deserializer=v1_dot_sales_dot_order__pb2.OrderUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__pb2.OrderUpdateResponse.SerializeToString,
        ),
        "OrderDelete": grpc.unary_unary_rpc_method_handler(
            servicer.OrderDelete,
            request_deserializer=v1_dot_sales_dot_order__pb2.OrderDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__pb2.OrderDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.order.OrderService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class OrderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def OrderCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderCreate",
            v1_dot_sales_dot_order__pb2.OrderCreateRequest.SerializeToString,
            v1_dot_sales_dot_order__pb2.OrderCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderRead",
            v1_dot_sales_dot_order__pb2.OrderReadRequest.SerializeToString,
            v1_dot_sales_dot_order__pb2.OrderReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderUpdate",
            v1_dot_sales_dot_order__pb2.OrderUpdateRequest.SerializeToString,
            v1_dot_sales_dot_order__pb2.OrderUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.OrderService/OrderDelete",
            v1_dot_sales_dot_order__pb2.OrderDeleteRequest.SerializeToString,
            v1_dot_sales_dot_order__pb2.OrderDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from mongoengine.fields import EmbeddedDocumentField, ReferenceField
from mongoengine import DynamicEmbeddedDocument
from omni.pro.util import to_camel_case
from sqlalchemy import Enum, inspect
from sqlalchemy.orm.relationships import RelationshipProperty


class Descriptor(object):
    @staticmethod
    def describe_mongo_model(model, prefix_name="", prefix_code=""):
        """
        Describe the structure of a MongoDB model using its fields.

        Describir la estructura de un modelo de MongoDB usando sus campos.

        Parameters:
        ----------
        model : object
            MongoDB model to be described.
            Modelo de MongoDB a describir.

        prefix_name : str, optional
            Prefix for the field's display name.
            Prefijo para el nombre de visualización del campo. (default is "")

        prefix_code : str, optional
            Prefix for the field's code reference.
            Prefijo para la referencia de código del campo. (default is "")

        Returns:
        -------
        dict or list
            If it's a top-level call, returns a dictionary describing the main model.
            If it's a recursive call, returns a list describing the fields of an embedded or referenced model.

            Si es una llamada de nivel superior, devuelve un diccionario que describe el modelo principal.
            Si es una llamada recursiva, devuelve una lista que describe los campos de un modelo incrustado o referenciado.

        Usage:
        -----
        descriptor = Descriptor()
        description = descriptor.describe_mongo_model(SomeMongoModel)

        Uso:
        -----
        descriptor = Descriptor()
        descripcion = descriptor.describe_mongo_model(AlgúnModeloMongo)
        """
        fields = []

        for field_name, field in model._fields.items():
            current_name = (prefix_name + " " + to_camel_case(field_name)).strip()
            current_code = (prefix_code + "." + field_name).strip(".")

            field_info = {
                "name": current_name,
                "code": current_code,
                "type": field.__class__.__name__,
                "required": field.required,
                "relation": {},
            }
            if hasattr(field, "max_length") and field.max_length:
                field_info["size"] = field.max_length

            # If the field is an EmbeddedDocumentField or ReferenceField, recurse into its fields
            if isinstance(field, EmbeddedDocumentField) or isinstance(field, ReferenceField):
                embedded_model = field.document_type_obj
                try:
                    embedded_fields = Descriptor.describe_mongo_model(embedded_model, current_name, current_code)
                except RecursionError as e:
                    print(f"Model: {model.__name__} RecursionError: {e}")
                    continue
                fields.extend(embedded_fields)  # extend main fields list with the result of recursion
                continue  # we don't add a separate field for the embedded/reference field itself

            # if the field is an Enum, add options values
            if hasattr(field, "choices") and field.choices:
                field_info["options"] = [{"code": x.value, "name": to_camel_case(x.value)} for x in field.choices]

            fields.append(field_info)

        if model._dynamic:
            return [
                {
                    "name": prefix_name,
                    "code": prefix_code,
                    "type": "DynamicField",
                    "required": False,
                    "relation": {},
                }
            ] + fields

        if prefix_name == "" and prefix_code == "":  # This is a top-level call
            return {
                "name": model.__name__,
                "class_name": f"{model.__module__}.{model.__name__}",
                "code": model._meta.get("collection") or model.__name__.lower(),
                "fields": fields,
            }

        else:  # This is a recursive call
            return fields

    @staticmethod
    def describe_sqlalchemy_model(model):
        """
        Describe the structure of an SQLAlchemy model using its columns and relationships.

        Describir la estructura de un modelo SQLAlchemy usando sus columnas y relaciones.

        Parameters:
        ----------
        model : object
            SQLAlchemy model to be described.
            Modelo SQLAlchemy a describir.

        Returns:
        -------
        dict
            Dictionary describing the given SQLAlchemy model including its fields and relationships.

            Diccionario que describe el modelo SQLAlchemy dado incluyendo sus campos y relaciones.

        Usage:
        -----
        descriptor = Descriptor()
        description = descriptor.describe_sqlalchemy_model(SomeSQLAlchemyModel)

        Uso:
        -----
        descriptor = Descriptor()
        descripcion = descriptor.describe_sqlalchemy_model(AlgúnModeloSQLAlchemy)
        """
        mapper = inspect(model)

        description = {
            "name": model.__name__,
            "class_name": f"{model.__module__}.{model.__name__}",
            "code": mapper.mapped_table.name,
            "fields": [],
        }

        for column in mapper.columns:
            column_info = {
                "name": to_camel_case(column.name),
                "code": column.name,
                "type": column.type.__class__.__name__,
                "required": not column.nullable,
            }
            if hasattr(column.type, "length") and column.type.length:
                column_info["size"] = column.type.length

            if isinstance(column.type, Enum):
                column_info["options"] = [
                    {"code": x.value, "name": to_camel_case(x.value)} for x in column.type.enum_class
                ]

            if column.foreign_keys:
                # Aquí solo se toma el primer ForeignKey, hay que modificarlo si puede haber múltiples referencias.
                related_model = list(column.foreign_keys)[0].column.table.name
                column_info["relation"] = {"name": related_model}
            # column_info["relation"] = {}

            description["fields"].append(column_info)

        # Verificar relaciones (como many-to-one)
        for name, relation in mapper.relationships.items():
            if isinstance(relation, RelationshipProperty):
                relation_info = {
                    "name": name,
                    "code": name,
                    "type": "RelationshipProperty",
                    "required": not relation.uselist,  # True para many-to-one, False para many-to-many
                    "relation": {"name": relation.entity.class_.__name__},
                }
                description["fields"].append(relation_info)

        return description

    @staticmethod
    def describe_mongo_model_tree(model):
        """
        Describe the hierarchical structure of a MongoDB model, including embedded or referenced models.

        Describir la estructura jerárquica de un modelo MongoDB, incluyendo modelos incrustados o referenciados.

        Parameters:
        ----------
        model : object
            MongoDB model to be described hierarchically.
            Modelo de MongoDB a describir jerárquicamente.

        Returns:
        -------
        dict
            Dictionary describing the given MongoDB model in a hierarchical manner including its fields,
            relations, and embedded/referenced models.

            Diccionario que describe el modelo MongoDB dado de manera jerárquica, incluyendo sus campos,
            relaciones y modelos incrustados/referenciados.

        Usage:
        -----
        descriptor = Descriptor()
        description = descriptor.describe_mongo_model_tree(SomeMongoModel)

        Uso:
        -----
        descriptor = Descriptor()
        descripcion = descriptor.describe_mongo_model_tree(AlgúnModeloMongo)
        """
        description = {
            "name": model.__name__,
            "class_name": f"{model.__module__}.{model.__name__}",
            "code": model._meta.get("collection") or model.__name__.lower(),
            "fields": [],
        }
        for field_name, field in model._fields.items():
            field_info = {
                "name": to_camel_case(field_name),
                "code": field_name,
                "type": field.__class__.__name__,
                "required": field.required,
                # "relation": field.document_type.__name__ if isinstance(field, ReferenceField) else {},
                "relation": {},
            }
            if hasattr(field, "max_length") and field.max_length:
                field_info["size"] = field.max_length

            # If the field is an EmbeddedDocumentField, get its fields as well
            if isinstance(field, EmbeddedDocumentField) or isinstance(field, ReferenceField):
                # field_info["fields"] = Descriptor.describe_mongo_model_tree(field.document_type)["fields"]
                embedded_model = field.document_type_obj
                embedded_fields = Descriptor.describe_mongo_model_tree(embedded_model)
                field_info["relation"] = embedded_fields

            # if the field is a Enum, add options values
            if hasattr(field, "choices") and field.choices:
                field_info["options"] = [x.value for x in field.choices]

            description["fields"].append(field_info)

        return description



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/utilities/export.proto\x12$pro.omni.oms.api.v1.utilities.export\x1a\x11\x63ommon/base.proto"\x9d\x01\n\x12\x45xportModelRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\texport_to\x18\x02 \x01(\t\x12\x18\n\x10\x65xport_type_file\x18\x03 \x01(\t\x12\x0e\n\x06\x66ields\x18\x04 \x03(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13\x45xportModelResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x96\x01\n\rExportService\x12\x84\x01\n\x0b\x45xportModel\x12\x38.pro.omni.oms.api.v1.utilities.export.ExportModelRequest\x1a\x39.pro.omni.oms.api.v1.utilities.export.ExportModelResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_EXPORTMODELREQUEST"]._serialized_start = 87
    _globals["_EXPORTMODELREQUEST"]._serialized_end = 244
    _globals["_EXPORTMODELRESPONSE"]._serialized_start = 246
    _globals["_EXPORTMODELRESPONSE"]._serialized_end = 342
    _globals["_EXPORTSERVICE"]._serialized_start = 345
    _globals["_EXPORTSERVICE"]._serialized_end = 495
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/import_export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/import_export.proto\x12+pro.omni.oms.api.v1.utilities.import_export\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/model.proto"\xfa\x03\n\x0cImportExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0etype_operation\x18\x02 \x01(\t\x12\x39\n\x05model\x18\x03 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x11\n\tname_file\x18\x04 \x01(\t\x12\x11\n\ttype_file\x18\x05 \x01(\t\x12-\n\tdate_load\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12\x17\n\x0frequired_fields\x18\n \x03(\t\x12-\n\x0cprocess_data\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\nskip_error\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xcc\x02\n\x19ImportExportCreateRequest\x12\x16\n\x0etype_operation\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x11\n\tname_file\x18\x03 \x01(\t\x12\x11\n\ttype_file\x18\x04 \x01(\t\x12-\n\tdate_init\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x64\x61te_finish\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0frequired_fields\x18\x07 \x03(\t\x12.\n\nskip_error\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\t \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xf5\x02\n\x17ImportExportReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf2\x01\n\x18ImportExportReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12P\n\rimport_export\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xa5\x01\n\x19ImportExportUpdateRequest\x12P\n\rimport_export\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"_\n\x19ImportExportDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"Z\n\x14\x43onfirmUploadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x15\x43onfirmUploadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport2\xd2\x06\n\x13ImportExportService\x12\xa7\x01\n\x12ImportExportCreate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateResponse"\x00\x12\xa1\x01\n\x10ImportExportRead\x12\x44.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadResponse"\x00\x12\xa7\x01\n\x12ImportExportUpdate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateResponse"\x00\x12\xa7\x01\n\x12ImportExportDelete\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteResponse"\x00\x12\x98\x01\n\rConfirmUpload\x12\x41.pro.omni.oms.api.v1.utilities.import_export.ConfirmUploadRequest\x1a\x42.pro.omni.oms.api.v1.utilities.import_export.ConfirmUploadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.import_export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_IMPORTEXPORT"]._serialized_start = 222
    _globals["_IMPORTEXPORT"]._serialized_end = 728
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_start = 731
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_end = 1063
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_start = 1066
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_end = 1251
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_start = 1254
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_end = 1627
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_start = 1630
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_end = 1872
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_start = 1875
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_end = 2040
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_start = 2043
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_end = 2228
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_start = 2230
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_end = 2325
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_start = 2328
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_end = 2513
    _globals["_CONFIRMUPLOADREQUEST"]._serialized_start = 2515
    _globals["_CONFIRMUPLOADREQUEST"]._serialized_end = 2605
    _globals["_CONFIRMUPLOADRESPONSE"]._serialized_start = 2608
    _globals["_CONFIRMUPLOADRESPONSE"]._serialized_end = 2788
    _globals["_IMPORTEXPORTSERVICE"]._serialized_start = 2791
    _globals["_IMPORTEXPORTSERVICE"]._serialized_end = 3641
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import python_code_pb2 as v1_dot_rules_dot_python__code__pb2


class PythonCodeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PythonCodeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeCreate",
            request_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeResponse.FromString,
        )
        self.PythonCodeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeRead",
            request_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeReadResponse.FromString,
        )
        self.PythonCodeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeUpdate",
            request_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateResponse.FromString,
        )
        self.PythonCodeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeDelete",
            request_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteResponse.FromString,
        )


class PythonCodeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PythonCodeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PythonCodeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PythonCodeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PythonCodeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PythonCodeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PythonCodeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PythonCodeCreate,
            request_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeRequest.FromString,
            response_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeResponse.SerializeToString,
        ),
        "PythonCodeRead": grpc.unary_unary_rpc_method_handler(
            servicer.PythonCodeRead,
            request_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeReadResponse.SerializeToString,
        ),
        "PythonCodeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PythonCodeUpdate,
            request_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateResponse.SerializeToString,
        ),
        "PythonCodeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PythonCodeDelete,
            request_deserializer=v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.python_code.PythonCodeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PythonCodeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PythonCodeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeCreate",
            v1_dot_rules_dot_python__code__pb2.PythonCodeRequest.SerializeToString,
            v1_dot_rules_dot_python__code__pb2.PythonCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PythonCodeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeRead",
            v1_dot_rules_dot_python__code__pb2.PythonCodeReadRequest.SerializeToString,
            v1_dot_rules_dot_python__code__pb2.PythonCodeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PythonCodeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeUpdate",
            v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateRequest.SerializeToString,
            v1_dot_rules_dot_python__code__pb2.PythonCodeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PythonCodeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.python_code.PythonCodeService/PythonCodeDelete",
            v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteRequest.SerializeToString,
            v1_dot_rules_dot_python__code__pb2.PythonCodeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from enum import Enum, unique
from abc import ABC, abstractmethod


@unique
class FilesType(Enum):
    CSV = "csv"
    XLSX = "xlsx"
    JSON = "json"

    @classmethod
    def valid_value(cls, value: str) -> bool:
        return value in cls._value2member_map_


class DocumentStrategy(ABC):
    """
    Abstract base class defining the interface for document handling strategies.
    """

    @abstractmethod
    def open_file(self, file_path):
        """
        Opens and reads a file from the given file path.
        :param file_path: Path of the file to be opened.
        """
        pass

    @abstractmethod
    def get_data(self, file_path):
        """
        Gets the data from the file.
        :param file_path: Path of the file to be opened.
        """
        pass

    @abstractmethod
    def add_data(self, file_path, data):
        """
        Adds data to the file.
        :param file_path: Path of the file to be opened.
        :param data: Data to be added to the file.
        """
        pass

    @abstractmethod
    def validate(self, expected, file_path):
        """
        Validates the file against the expected criteria.
        :param expected: Expected criteria to validate.
        :param file_path: Path of the file to be validated.
        """
        pass


class CSVDocumentStrategy(DocumentStrategy):
    """
    Strategy for handling CSV documents.
    """

    def __init__(self, file_library, **kwargs):
        """
        Initializes the CSVDocumentStrategy.
        :param file_library: Library to be used for reading files.
        """
        self.file_library = file_library

    def open_file(self, file_path):
        """
        Opens and reads a CSV file using the specified file library.
        :param file_path: Path of the CSV file to be opened.
        :return: DataFrame object of the opened file.
        """
        return self.file_library.read_csv(file_path)

    def get_data(self, file_path):
        """
        Opens and reads a CSV file using the specified file library.
        :param file_path: Path of the CSV file to be opened.
        :return: List of dictionaries of the opened file.
        """
        import numpy as np

        csv_file = self.open_file(file_path)
        csv_file.replace({np.nan: None}, inplace=True)
        return csv_file.to_dict(orient="records")

    def add_data(self, file_path, data):
        """
        Adds data to the CSV file.
        :param file_path: Path of the CSV file to be opened.
        :param data: Data to be added to the CSV file.
        """

        csv_data = self.file_library.DataFrame(data)
        csv_data.to_csv(file_path, index=False)

    def validate(self, expected, file_path):
        """
        Validates the headers of the CSV file.
        :param expected: List of expected headers.
        :param file_path: Path of the CSV file to be validated.
        """
        csv_file = self.open_file(file_path)
        actual_headers = csv_file.columns.tolist()
        if set(expected) != set(actual_headers):
            raise ValueError("Csv headers do not match the expected model headers")


class JSONDocumentStrategy(DocumentStrategy):
    """
    Strategy for handling JSON files.
    """

    def __init__(self, file_library, **kwargs):
        """
        Initializes the JSONDocumentStrategy.
        :param file_library: Library to be used for reading files.
        """
        self.file_library = file_library

    def open_file(self, file_path):
        """
        Opens and reads a JSON file using the specified file library.
        :param file_path: Path of the JSON file to be opened.
        :return: DataFrame object of the opened file.
        """
        return self.file_library.read_json(file_path)

    def get_data(self, file_path):
        """
        Opens and reads a JSON file using the specified file library.
        :param file_path: Path of the JSON file to be opened.
        :return: List of dictionaries of the opened file.
        """
        import numpy as np

        json_file = self.open_file(file_path)
        json_file.replace({np.nan: None}, inplace=True)
        return json_file.to_dict(orient="records")

    def add_data(self, file_path, data):
        """
        Adds data to the JSON file.
        :param file_path: Path of the JSON file to be opened.
        :param data: Data to be added to the JSON file.
        """
        json_data = self.file_library.DataFrame(data)
        json_data.to_json(file_path, orient="records", lines=True)

    def validate(self, expected, file_path):
        """
        Validates the headers of the JSON file.
        :param expected: List of expected headers.
        :param file_path: Path of the JSON file to be validated.
        """
        json_file = self.open_file(file_path)
        actual_headers = json_file.columns.tolist()
        if set(expected) != set(actual_headers):
            raise ValueError("JSON headers do not match the expected model headers")


class ExcelDocumentStrategy(DocumentStrategy):
    """
    Strategy for handling Excel documents.
    """

    def __init__(self, file_library, **kwargs):
        """
        Initializes the ExcelDocumentStrategy.
        :param file_library: Library to be used for reading files.
        """
        self.file_library = file_library

    def open_file(self, file_path):
        """
        To be implemented for opening Excel files.
        """
        raise NotImplementedError

    def validate(self, expected, file_path):
        """
        To be implemented for validating Excel files.
        """
        raise NotImplementedError


class FileProcessor:
    """
    Processor class for handling different types of  files.
    """

    def __init__(self, allowed_extensions: list = []):
        """
        Initializes the FileProcessor with allowed file extensions.
        :param allowed_extensions: List of allowed file extensions.
        """
        self.document_strategies = {
            FilesType.CSV: CSVDocumentStrategy,
            FilesType.XLSX: ExcelDocumentStrategy,
            FilesType.JSON: JSONDocumentStrategy,
        }
        self.allowed_extensions = allowed_extensions

    def allowed_extension(self, extension):
        """
        Checks if the given extension is allowed.
        :param extension: Extension to check.
        :return: Boolean indicating if the extension is allowed.
        """
        return extension in self.allowed_extensions

    def get_document_processor(self, file_type: FilesType, file_library: object):
        """
        Retrieves the appropriate file processor based on the file type.
        :param file_type: Type of the document file.
        :param file_library: Library to be used for reading files.
        :return: An instance of the corresponding document strategy.
        """
        if not self.allowed_extension(file_type.value):
            raise ValueError("Document type not allowed")

        strategy_class = self.document_strategies.get(file_type)
        if strategy_class is None:
            raise ValueError("Document type not supported")

        return strategy_class(file_library)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/stock/delivery_method.proto\x12)pro.omni.oms.api.v1.stock.delivery_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xcc\x01\n\x0e\x44\x65liveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65livery_method_doc_id\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAuditb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYMETHOD"]._serialized_start = 162
    _globals["_DELIVERYMETHOD"]._serialized_end = 366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/order.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import address_pb2 as v1_dot_sales_dot_address__pb2
from omni.pro.protos.v1.sales import delivery_method_pb2 as v1_dot_sales_dot_delivery__method__pb2
from omni.pro.protos.v1.sales import sale_pb2 as v1_dot_sales_dot_sale__pb2
from omni.pro.protos.v1.sales import warehouse_pb2 as v1_dot_sales_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/sales/order.proto\x12\x1fpro.omni.oms.api.v1.sales.order\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16v1/sales/address.proto\x1a\x13v1/sales/sale.proto\x1a\x1ev1/sales/delivery_method.proto\x1a\x18v1/sales/warehouse.proto"\x89\x04\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x04sale\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.sale.Sale\x12@\n\x0cship_address\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12R\n\x0f\x64\x65livery_method\x18\x05 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x11\n\ttax_total\x18\x06 \x01(\x02\x12\x16\n\x0e\x64iscount_total\x18\x07 \x01(\x02\x12\x10\n\x08subtotal\x18\x08 \x01(\x02\x12\r\n\x05total\x18\t \x01(\x02\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12\x41\n\twarehouse\x18\x0c \x01(\x0b\x32..pro.omni.oms.api.v1.sales.warehouse.Warehouse\x12\x0b\n\x03\x63id\x18\r \x01(\t\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa6\x02\n\x12OrderCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07sale_id\x18\x02 \x01(\x05\x12\x19\n\x11ship_address_code\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65livery_method_id\x18\x04 \x01(\x05\x12\x11\n\ttax_total\x18\x05 \x01(\x02\x12\x16\n\x0e\x64iscount_total\x18\x06 \x01(\x02\x12\x10\n\x08subtotal\x18\x07 \x01(\x02\x12\r\n\x05total\x18\x08 \x01(\x02\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x14\n\x0cwarehouse_id\x18\n \x01(\x05\x12\x0b\n\x03\x63id\x18\x0b \x01(\t\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13OrderCreateResponse\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x02\n\x10OrderReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11OrderReadResponse\x12\x36\n\x06orders\x18\x01 \x03(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x83\x01\n\x12OrderUpdateRequest\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13OrderUpdateResponse\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"X\n\x12OrderDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13OrderDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cOrderService\x12z\n\x0bOrderCreate\x12\x33.pro.omni.oms.api.v1.sales.order.OrderCreateRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderCreateResponse"\x00\x12t\n\tOrderRead\x12\x31.pro.omni.oms.api.v1.sales.order.OrderReadRequest\x1a\x32.pro.omni.oms.api.v1.sales.order.OrderReadResponse"\x00\x12z\n\x0bOrderUpdate\x12\x33.pro.omni.oms.api.v1.sales.order.OrderUpdateRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderUpdateResponse"\x00\x12z\n\x0bOrderDelete\x12\x33.pro.omni.oms.api.v1.sales.order.OrderDeleteRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.order_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ORDER"]._serialized_start = 212
    _globals["_ORDER"]._serialized_end = 733
    _globals["_ORDERCREATEREQUEST"]._serialized_start = 736
    _globals["_ORDERCREATEREQUEST"]._serialized_end = 1030
    _globals["_ORDERCREATERESPONSE"]._serialized_start = 1033
    _globals["_ORDERCREATERESPONSE"]._serialized_end = 1184
    _globals["_ORDERREADREQUEST"]._serialized_start = 1187
    _globals["_ORDERREADREQUEST"]._serialized_end = 1553
    _globals["_ORDERREADRESPONSE"]._serialized_start = 1556
    _globals["_ORDERREADRESPONSE"]._serialized_end = 1765
    _globals["_ORDERUPDATEREQUEST"]._serialized_start = 1768
    _globals["_ORDERUPDATEREQUEST"]._serialized_end = 1899
    _globals["_ORDERUPDATERESPONSE"]._serialized_start = 1902
    _globals["_ORDERUPDATERESPONSE"]._serialized_end = 2053
    _globals["_ORDERDELETEREQUEST"]._serialized_start = 2055
    _globals["_ORDERDELETEREQUEST"]._serialized_end = 2143
    _globals["_ORDERDELETERESPONSE"]._serialized_start = 2145
    _globals["_ORDERDELETERESPONSE"]._serialized_end = 2241
    _globals["_ORDERSERVICE"]._serialized_start = 2244
    _globals["_ORDERSERVICE"]._serialized_end = 2748
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class QueryStockRequest(_message.Message):
    __slots__ = ["query", "context"]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    query: str
    context: _base_pb2.Context
    def __init__(
        self, query: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class QueryStockResponse(_message.Message):
    __slots__ = ["response_standard", "query"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    query: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        query: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/quant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import product_pb2 as v1_dot_stock_dot_product__pb2
from omni.pro.protos.v1.stock import uom_pb2 as v1_dot_stock_dot_uom__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/quant.proto\x12\x1fpro.omni.oms.api.v1.stock.quant\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17v1/stock/location.proto\x1a\x16v1/stock/product.proto\x1a\x12v1/stock/uom.proto"\x9a\x03\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\x05\x12;\n\x07product\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product\x12>\n\x08location\x18\x03 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x0c\n\x04lote\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12\x19\n\x11reserved_quantity\x18\x06 \x01(\x02\x12\x10\n\x08quantity\x18\x07 \x01(\x02\x12/\n\x03uom\x18\x08 \x01(\x0b\x32".pro.omni.oms.api.v1.stock.uom.Uom\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\n \x01(\t\x12?\n\x0cobject_audit\x18\x0b \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf1\x01\n\x12QuantCreateRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x13\n\x0blocation_id\x18\x02 \x01(\x05\x12\x0c\n\x04lote\x18\x03 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x19\n\x11reserved_quantity\x18\x05 \x01(\x02\x12\x10\n\x08quantity\x18\x06 \x01(\x02\x12\x0e\n\x06uom_id\x18\x07 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12\x36\n\x07\x63ontext\x18\t \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11QuantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x06quants\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\x83\x01\n\x12QuantUpdateRequest\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"X\n\x12QuantDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x94\x01\n\x10ProductAvailable\x12-\n\tavailable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x12\x61vailable_quantity\x18\x02 \x01(\x02\x12\x35\n\x05quant\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\xaa\x01\n\x17ProductAvailableRequest\x12\x13\n\x0blocation_id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x13\n\x0bproduct_sku\x18\x03 \x01(\t\x12\x19\n\x11required_quantity\x18\x04 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb3\x01\n\x18ProductAvailableResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12L\n\x11product_available\x18\x02 \x01(\x0b\x32\x31.pro.omni.oms.api.v1.stock.quant.ProductAvailable2\x84\x05\n\x0cQuantService\x12z\n\x0bQuantCreate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantCreateResponse"\x00\x12t\n\tQuantRead\x12\x31.pro.omni.oms.api.v1.stock.quant.QuantReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.quant.QuantReadResponse"\x00\x12z\n\x0bQuantUpdate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantUpdateResponse"\x00\x12z\n\x0bQuantDelete\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantDeleteResponse"\x00\x12\x89\x01\n\x10ProductAvailable\x12\x38.pro.omni.oms.api.v1.stock.quant.ProductAvailableRequest\x1a\x39.pro.omni.oms.api.v1.stock.quant.ProductAvailableResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.quant_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUANT"]._serialized_start = 178
    _globals["_QUANT"]._serialized_end = 588
    _globals["_QUANTCREATEREQUEST"]._serialized_start = 591
    _globals["_QUANTCREATEREQUEST"]._serialized_end = 832
    _globals["_QUANTCREATERESPONSE"]._serialized_start = 835
    _globals["_QUANTCREATERESPONSE"]._serialized_end = 986
    _globals["_QUANTREADREQUEST"]._serialized_start = 989
    _globals["_QUANTREADREQUEST"]._serialized_end = 1355
    _globals["_QUANTREADRESPONSE"]._serialized_start = 1358
    _globals["_QUANTREADRESPONSE"]._serialized_end = 1567
    _globals["_QUANTUPDATEREQUEST"]._serialized_start = 1570
    _globals["_QUANTUPDATEREQUEST"]._serialized_end = 1701
    _globals["_QUANTUPDATERESPONSE"]._serialized_start = 1704
    _globals["_QUANTUPDATERESPONSE"]._serialized_end = 1855
    _globals["_QUANTDELETEREQUEST"]._serialized_start = 1857
    _globals["_QUANTDELETEREQUEST"]._serialized_end = 1945
    _globals["_QUANTDELETERESPONSE"]._serialized_start = 1947
    _globals["_QUANTDELETERESPONSE"]._serialized_end = 2043
    _globals["_PRODUCTAVAILABLE"]._serialized_start = 2046
    _globals["_PRODUCTAVAILABLE"]._serialized_end = 2194
    _globals["_PRODUCTAVAILABLEREQUEST"]._serialized_start = 2197
    _globals["_PRODUCTAVAILABLEREQUEST"]._serialized_end = 2367
    _globals["_PRODUCTAVAILABLERESPONSE"]._serialized_start = 2370
    _globals["_PRODUCTAVAILABLERESPONSE"]._serialized_end = 2549
    _globals["_QUANTSERVICE"]._serialized_start = 2552
    _globals["_QUANTSERVICE"]._serialized_end = 3196
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/stock_security.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dv1/rules/stock_security.proto\x12(pro.omni.oms.api.v1.rules.stock_security\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"V\n\x14ProductStockSecurity\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x0b\n\x03sku\x18\x02 \x01(\t\x12\x19\n\x11quantity_security\x18\x03 \x01(\x02"\x99\x02\n\rStockSecurity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12P\n\x08products\x18\x05 \x03(\x0b\x32>.pro.omni.oms.api.v1.rules.stock_security.ProductStockSecurity\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe5\x01\n\x1aStockSecurityCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12P\n\x08products\x18\x04 \x03(\x0b\x32>.pro.omni.oms.api.v1.rules.stock_security.ProductStockSecurity\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1bStockSecurityCreateResponse\x12O\n\x0estock_security\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.stock_security.StockSecurity\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf6\x02\n\x18StockSecurityReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf2\x01\n\x19StockSecurityReadResponse\x12O\n\x0estock_security\x18\x01 \x03(\x0b\x32\x37.pro.omni.oms.api.v1.rules.stock_security.StockSecurity\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa5\x01\n\x1aStockSecurityUpdateRequest\x12O\n\x0estock_security\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.stock_security.StockSecurity\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1bStockSecurityUpdateResponse\x12O\n\x0estock_security\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.stock_security.StockSecurity\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"`\n\x1aStockSecurityDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1bStockSecurityDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xac\x05\n\x14StockSecurityService\x12\xa4\x01\n\x13StockSecurityCreate\x12\x44.pro.omni.oms.api.v1.rules.stock_security.StockSecurityCreateRequest\x1a\x45.pro.omni.oms.api.v1.rules.stock_security.StockSecurityCreateResponse"\x00\x12\x9e\x01\n\x11StockSecurityRead\x12\x42.pro.omni.oms.api.v1.rules.stock_security.StockSecurityReadRequest\x1a\x43.pro.omni.oms.api.v1.rules.stock_security.StockSecurityReadResponse"\x00\x12\xa4\x01\n\x13StockSecurityUpdate\x12\x44.pro.omni.oms.api.v1.rules.stock_security.StockSecurityUpdateRequest\x1a\x45.pro.omni.oms.api.v1.rules.stock_security.StockSecurityUpdateResponse"\x00\x12\xa4\x01\n\x13StockSecurityDelete\x12\x44.pro.omni.oms.api.v1.rules.stock_security.StockSecurityDeleteRequest\x1a\x45.pro.omni.oms.api.v1.rules.stock_security.StockSecurityDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.stock_security_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PRODUCTSTOCKSECURITY"]._serialized_start = 126
    _globals["_PRODUCTSTOCKSECURITY"]._serialized_end = 212
    _globals["_STOCKSECURITY"]._serialized_start = 215
    _globals["_STOCKSECURITY"]._serialized_end = 496
    _globals["_STOCKSECURITYCREATEREQUEST"]._serialized_start = 499
    _globals["_STOCKSECURITYCREATEREQUEST"]._serialized_end = 728
    _globals["_STOCKSECURITYCREATERESPONSE"]._serialized_start = 731
    _globals["_STOCKSECURITYCREATERESPONSE"]._serialized_end = 916
    _globals["_STOCKSECURITYREADREQUEST"]._serialized_start = 919
    _globals["_STOCKSECURITYREADREQUEST"]._serialized_end = 1293
    _globals["_STOCKSECURITYREADRESPONSE"]._serialized_start = 1296
    _globals["_STOCKSECURITYREADRESPONSE"]._serialized_end = 1538
    _globals["_STOCKSECURITYUPDATEREQUEST"]._serialized_start = 1541
    _globals["_STOCKSECURITYUPDATEREQUEST"]._serialized_end = 1706
    _globals["_STOCKSECURITYUPDATERESPONSE"]._serialized_start = 1709
    _globals["_STOCKSECURITYUPDATERESPONSE"]._serialized_end = 1894
    _globals["_STOCKSECURITYDELETEREQUEST"]._serialized_start = 1896
    _globals["_STOCKSECURITYDELETEREQUEST"]._serialized_end = 1992
    _globals["_STOCKSECURITYDELETERESPONSE"]._serialized_start = 1994
    _globals["_STOCKSECURITYDELETERESPONSE"]._serialized_end = 2098
    _globals["_STOCKSECURITYSERVICE"]._serialized_start = 2101
    _globals["_STOCKSECURITYSERVICE"]._serialized_end = 2785
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = [
        "id",
        "name",
        "sub",
        "tenant",
        "username",
        "email",
        "language",
        "timezone",
        "groups",
        "is_superuser",
        "active",
        "mfa",
        "external_id",
        "type",
        "password",
        "object_audit",
        "permissions",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SUB_FIELD_NUMBER: _ClassVar[int]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    MFA_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    sub: str
    tenant: str
    username: str
    email: str
    language: _base_pb2.Object
    timezone: _base_pb2.Object
    groups: _struct_pb2.ListValue
    is_superuser: _wrappers_pb2.BoolValue
    active: _wrappers_pb2.BoolValue
    mfa: _wrappers_pb2.BoolValue
    external_id: str
    type: str
    password: str
    object_audit: _base_pb2.ObjectAudit
    permissions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        sub: _Optional[str] = ...,
        tenant: _Optional[str] = ...,
        username: _Optional[str] = ...,
        email: _Optional[str] = ...,
        language: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        timezone: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        groups: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        is_superuser: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        mfa: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        type: _Optional[str] = ...,
        password: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
        permissions: _Optional[_Iterable[str]] = ...,
    ) -> None: ...

class Group(_message.Message):
    __slots__ = ["id", "name", "code", "access", "active", "external_id", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ACCESS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    access: _struct_pb2.ListValue
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        access: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class Action(_message.Message):
    __slots__ = ["id", "name", "code", "description", "microservice", "model", "active", "external_id", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MICROSERVICE_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    description: str
    microservice: str
    model: str
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        description: _Optional[str] = ...,
        microservice: _Optional[str] = ...,
        model: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class Access(_message.Message):
    __slots__ = ["id", "name", "code", "domain", "action_id", "action", "active", "external_id", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    domain: str
    action_id: str
    action: Action
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        domain: _Optional[str] = ...,
        action_id: _Optional[str] = ...,
        action: _Optional[_Union[Action, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class UserCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "username",
        "email",
        "email_confirm",
        "password",
        "password_confirm",
        "groups_ids",
        "is_superuser",
        "language",
        "timezone",
        "external_id",
        "type",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_CONFIRM_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_CONFIRM_FIELD_NUMBER: _ClassVar[int]
    GROUPS_IDS_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    username: str
    email: str
    email_confirm: str
    password: str
    password_confirm: str
    groups_ids: _struct_pb2.ListValue
    is_superuser: _wrappers_pb2.BoolValue
    language: _base_pb2.Object
    timezone: _base_pb2.Object
    external_id: str
    type: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        username: _Optional[str] = ...,
        email: _Optional[str] = ...,
        email_confirm: _Optional[str] = ...,
        password: _Optional[str] = ...,
        password_confirm: _Optional[str] = ...,
        groups_ids: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        is_superuser: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        language: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        timezone: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        type: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserCreateResponse(_message.Message):
    __slots__ = ["response_standard", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...

class UserReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "users"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...,
    ) -> None: ...

class UserUpdateRequest(_message.Message):
    __slots__ = ["user", "context"]
    USER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    user: User
    context: _base_pb2.Context
    def __init__(
        self,
        user: _Optional[_Union[User, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...

class UserDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class UserDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class UserChangePasswordRequest(_message.Message):
    __slots__ = ["id", "password", "password_confirm", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_CONFIRM_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    password: str
    password_confirm: str
    context: _base_pb2.Context
    def __init__(
        self,
        id: _Optional[str] = ...,
        password: _Optional[str] = ...,
        password_confirm: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserChangePasswordResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class UserChangeEmailRequest(_message.Message):
    __slots__ = ["id", "email", "email_confirm", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_CONFIRM_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    email: str
    email_confirm: str
    context: _base_pb2.Context
    def __init__(
        self,
        id: _Optional[str] = ...,
        email: _Optional[str] = ...,
        email_confirm: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UserChangeEmailResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class GroupCreateRequest(_message.Message):
    __slots__ = ["name", "code", "access_ids", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ACCESS_IDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    access_ids: _struct_pb2.ListValue
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        access_ids: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupCreateResponse(_message.Message):
    __slots__ = ["response_standard", "group"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    group: Group
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        group: _Optional[_Union[Group, _Mapping]] = ...,
    ) -> None: ...

class GroupReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "groups"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    groups: _containers.RepeatedCompositeFieldContainer[Group]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        groups: _Optional[_Iterable[_Union[Group, _Mapping]]] = ...,
    ) -> None: ...

class GroupUpdateRequest(_message.Message):
    __slots__ = ["group", "context"]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group: Group
    context: _base_pb2.Context
    def __init__(
        self,
        group: _Optional[_Union[Group, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "group"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    group: Group
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        group: _Optional[_Union[Group, _Mapping]] = ...,
    ) -> None: ...

class GroupDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class GroupDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ActionCreateRequest(_message.Message):
    __slots__ = ["name", "code", "description", "microservice", "model", "external_id", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    MICROSERVICE_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    description: str
    microservice: str
    model: str
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        description: _Optional[str] = ...,
        microservice: _Optional[str] = ...,
        model: _Optional[str] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ActionCreateResponse(_message.Message):
    __slots__ = ["response_standard", "action"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    action: Action
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        action: _Optional[_Union[Action, _Mapping]] = ...,
    ) -> None: ...

class ActionReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ActionReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "actions"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    actions: _containers.RepeatedCompositeFieldContainer[Action]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        actions: _Optional[_Iterable[_Union[Action, _Mapping]]] = ...,
    ) -> None: ...

class ActionUpdateRequest(_message.Message):
    __slots__ = ["action", "context"]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    action: Action
    context: _base_pb2.Context
    def __init__(
        self,
        action: _Optional[_Union[Action, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ActionUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "action"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    action: Action
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        action: _Optional[_Union[Action, _Mapping]] = ...,
    ) -> None: ...

class ActionDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ActionDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AccessCreateRequest(_message.Message):
    __slots__ = ["name", "code", "domain", "action_id", "external_id", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    ACTION_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    domain: str
    action_id: str
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        domain: _Optional[str] = ...,
        action_id: _Optional[str] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AccessCreateResponse(_message.Message):
    __slots__ = ["response_standard", "access"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ACCESS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    access: Access
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        access: _Optional[_Union[Access, _Mapping]] = ...,
    ) -> None: ...

class AccessReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AccessReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "accesses"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    ACCESSES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    accesses: _containers.RepeatedCompositeFieldContainer[Access]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        accesses: _Optional[_Iterable[_Union[Access, _Mapping]]] = ...,
    ) -> None: ...

class AccessUpdateRequest(_message.Message):
    __slots__ = ["access", "context"]
    ACCESS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    access: Access
    context: _base_pb2.Context
    def __init__(
        self,
        access: _Optional[_Union[Access, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AccessUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "access"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ACCESS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    access: Access
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        access: _Optional[_Union[Access, _Mapping]] = ...,
    ) -> None: ...

class AccessDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class AccessDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AccessGroupRequest(_message.Message):
    __slots__ = ["access_ids", "group_id", "external_id", "context"]
    ACCESS_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    access_ids: _struct_pb2.ListValue
    group_id: str
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        access_ids: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        group_id: _Optional[str] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AccessGroupResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class GroupUserRequest(_message.Message):
    __slots__ = ["group_ids", "user_id", "context"]
    GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_ids: _struct_pb2.ListValue
    user_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_ids: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        user_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupUserResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class HasPermissionRequest(_message.Message):
    __slots__ = ["username", "permission", "context"]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    username: str
    permission: str
    context: _base_pb2.Context
    def __init__(
        self,
        username: _Optional[str] = ...,
        permission: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class HasPermissionResponse(_message.Message):
    __slots__ = ["response_standard", "has_permission", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    HAS_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    has_permission: bool
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        has_permission: bool = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...

class LoginRequest(_message.Message):
    __slots__ = ["username", "password", "context"]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    username: str
    password: str
    context: _base_pb2.Context
    def __init__(
        self,
        username: _Optional[str] = ...,
        password: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TokenRequest(_message.Message):
    __slots__ = ["client_id", "client_secret", "context"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    context: _base_pb2.Context
    def __init__(
        self,
        client_id: _Optional[str] = ...,
        client_secret: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TokenResponse(_message.Message):
    __slots__ = ["response_standard", "authentication_result"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_RESULT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    authentication_result: AuthenticationResult
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        authentication_result: _Optional[_Union[AuthenticationResult, _Mapping]] = ...,
    ) -> None: ...

class AuthenticationResult(_message.Message):
    __slots__ = ["token", "refresh_token", "expires_in"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    token: str
    refresh_token: str
    expires_in: int
    def __init__(
        self, token: _Optional[str] = ..., refresh_token: _Optional[str] = ..., expires_in: _Optional[int] = ...
    ) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ["response_standard", "authentication_result", "user"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_RESULT_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    authentication_result: AuthenticationResult
    user: User
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        authentication_result: _Optional[_Union[AuthenticationResult, _Mapping]] = ...,
        user: _Optional[_Union[User, _Mapping]] = ...,
    ) -> None: ...

class RefreshTokenRequest(_message.Message):
    __slots__ = ["context", "refresh_token"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    refresh_token: str
    def __init__(
        self, context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ..., refresh_token: _Optional[str] = ...
    ) -> None: ...

class RefreshTokenResponse(_message.Message):
    __slots__ = ["response_standard", "authentication_result"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_RESULT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    authentication_result: AuthenticationResult
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        authentication_result: _Optional[_Union[AuthenticationResult, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/webhook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import event_pb2 as v1_dot_utilities_dot_event__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/utilities/webhook.proto\x12%pro.omni.oms.api.v1.utilities.webhook\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/event.proto"\x93\x02\n\x07Webhook\x12\n\n\x02id\x18\x01 \x01(\t\x12\x39\n\x05\x65vent\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.event.Event\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0e\n\x06method\x18\x04 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t\x12\'\n\x03log\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb6\x01\n\x14WebhookCreateRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\'\n\x03log\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15WebhookCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07webhook\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.webhook.Webhook"\xf0\x02\n\x12WebhookReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x13WebhookReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12@\n\x08webhooks\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.utilities.webhook.Webhook"\x8f\x01\n\x14WebhookUpdateRequest\x12?\n\x07webhook\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.webhook.Webhook\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15WebhookUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07webhook\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.webhook.Webhook"Z\n\x14WebhookDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15WebhookDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc6\x04\n\x0eWebhookService\x12\x8c\x01\n\rWebhookCreate\x12;.pro.omni.oms.api.v1.utilities.webhook.WebhookCreateRequest\x1a<.pro.omni.oms.api.v1.utilities.webhook.WebhookCreateResponse"\x00\x12\x86\x01\n\x0bWebhookRead\x12\x39.pro.omni.oms.api.v1.utilities.webhook.WebhookReadRequest\x1a:.pro.omni.oms.api.v1.utilities.webhook.WebhookReadResponse"\x00\x12\x8c\x01\n\rWebhookUpdate\x12;.pro.omni.oms.api.v1.utilities.webhook.WebhookUpdateRequest\x1a<.pro.omni.oms.api.v1.utilities.webhook.WebhookUpdateResponse"\x00\x12\x8c\x01\n\rWebhookDelete\x12;.pro.omni.oms.api.v1.utilities.webhook.WebhookDeleteRequest\x1a<.pro.omni.oms.api.v1.utilities.webhook.WebhookDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.webhook_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WEBHOOK"]._serialized_start = 147
    _globals["_WEBHOOK"]._serialized_end = 422
    _globals["_WEBHOOKCREATEREQUEST"]._serialized_start = 425
    _globals["_WEBHOOKCREATEREQUEST"]._serialized_end = 607
    _globals["_WEBHOOKCREATERESPONSE"]._serialized_start = 610
    _globals["_WEBHOOKCREATERESPONSE"]._serialized_end = 773
    _globals["_WEBHOOKREADREQUEST"]._serialized_start = 776
    _globals["_WEBHOOKREADREQUEST"]._serialized_end = 1144
    _globals["_WEBHOOKREADRESPONSE"]._serialized_start = 1147
    _globals["_WEBHOOKREADRESPONSE"]._serialized_end = 1368
    _globals["_WEBHOOKUPDATEREQUEST"]._serialized_start = 1371
    _globals["_WEBHOOKUPDATEREQUEST"]._serialized_end = 1514
    _globals["_WEBHOOKUPDATERESPONSE"]._serialized_start = 1517
    _globals["_WEBHOOKUPDATERESPONSE"]._serialized_end = 1680
    _globals["_WEBHOOKDELETEREQUEST"]._serialized_start = 1682
    _globals["_WEBHOOKDELETEREQUEST"]._serialized_end = 1772
    _globals["_WEBHOOKDELETERESPONSE"]._serialized_start = 1774
    _globals["_WEBHOOKDELETERESPONSE"]._serialized_end = 1872
    _globals["_WEBHOOKSERVICE"]._serialized_start = 1875
    _globals["_WEBHOOKSERVICE"]._serialized_end = 2457
# @@protoc_insertion_point(module_scope)
